<?php
/**
 * Locale Auto Switch
 *
 * @package    Locale Auto Switch
 * @subpackage Locale Auto Switch Main Functions
/*
	Copyright (c) 2018- Katsushi Kawamori (email : dodesyoswift312@gmail.com)
	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; version 2 of the License.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

$localeautoswitch = new LocaleAutoSwitch();

/** ==================================================
 * Class Main function
 *
 * @since 1.00
 */
class LocaleAutoSwitch {

	/** ==================================================
	 * Languages
	 *
	 * @var $languages  languages.
	 */
	private $languages;

	/** ==================================================
	 * Locales
	 *
	 * @var $locale_wp_br_s  locale_wp_br_s.
	 */
	private $locale_wp_br_s;

	/** ==================================================
	 * Construct
	 *
	 * @since 1.00
	 */
	public function __construct() {

		$this->languages      = get_available_languages();
		$this->languages[]    = 'en_US';
		$this->locale_wp_br_s = json_decode( get_option( 'locale_auto_switch' ), true );

		add_filter( 'locale', array( $this, 'locale' ) );

	}

	/** ==================================================
	 * Swicth Locale
	 *
	 * @param  string $locale  locale.
	 * @return string $locale  locale.
	 * @since 1.00
	 */
	public function locale( $locale ) {
		return $this->switch_locale( $locale );
	}

	/** ==================================================
	 * Swicth Locale Main
	 *
	 * @param  string $locale  locale.
	 * @return string $locale  locale.
	 * @since 1.00
	 */
	private function switch_locale( $locale ) {

		if ( isset( $_SERVER['HTTP_ACCEPT_LANGUAGE'] ) ) {
			$lang = explode( ',', sanitize_text_field( wp_unslash( $_SERVER['HTTP_ACCEPT_LANGUAGE'] ) ) );
			foreach ( (array) $this->locale_wp_br_s as $locale_wp_br ) {
				if ( ! empty( $locale_wp_br['locale_br'] ) ) {
					foreach ( $locale_wp_br['locale_br'] as $locale_br ) {
						$locale_brs = explode( '|', $locale_br );
						foreach ( $locale_brs as $locale_b ) {
							if ( $locale_b === $lang[0] ) {
								if ( in_array( $locale_wp_br['locale_wp'], $this->languages, true ) ) {
									$locale = $locale_wp_br['locale_wp'];
									if ( is_admin() ) {
										update_user_meta( get_current_user_id(), 'locale', $locale );
									}
									return $locale;
								}
							}
						}
					}
				}
			}
			$locale = 'en_US';
			if ( is_admin() ) {
				update_user_meta( get_current_user_id(), 'locale', $locale );
			}
		}

		return $locale;

	}

}


